load_slab

Function load_slab 

pub fn load_slab(path: &str) -> Result<SignalSlab, WavError>
Load a WAV file into a SignalSlab ready for sampler hot-swap.

Performs all file I/O and allocations on the calling thread. The resulting SignalSlab can be sent to a sampler node via ParamValue::SignalSlab and consumed with zero allocations on the real-time I/O thread.